@@ -1,5 +1,6 @@
 # This file contains python variables that configure Lamson for email processing.
 from app.model import table
+from lamson import queue, routing
 import logging
 
 # configure logging to go to a log file
@@ -16,9 +17,12 @@ database_config = {
 }
 
 
-handlers = ['app.handlers.osb']
+handlers = ['app.handlers.post', 'app.handlers.comment']
 
-router_defaults = {'host': 'test\\.com', 'post_name': "[a-zA-Z0-9.]+"}
+router_defaults = {'host': 'oneshotblog\\.com', 
+                   'domain': "[a-zA-Z0-9.-]+\.[a-zA-Z]{2,4}",
+                   'user_id': "[a-zA-Z0-9._%+-]+",
+                   'post_name': "[a-zA-Z0-9][a-zA-Z0-9.]+"}
 
 template_config = {'dir': 'app', 'module': 'templates'}
 
@@ -29,3 +33,6 @@ queue_config = {'queue': 'run/posts', 'sleep': 10}
 
 queue_handlers = ['app.handlers.index']
 
+SPAM = {'db': 'app/spamdb', 'rc': 'spamrc', 'queue': 'run/spam'}
+
+routing.Router.UNDELIVERABLE_QUEUE=queue.Queue("run/undeliverable")
