@@ -2,12 +2,13 @@ from nose.tools import *
 from lamson.testing import *
 from lamson import view
 import os
-
+from glob import glob
 
 def test_spelling():
     message = {}
     original = {}
-    for template in ['confirm.msg','page_ready.msg', 'welcome.msg']:
+    for path in glob("app/templates/mail/*.msg"):
+        template = "mail/" + os.path.basename(path)
         result = view.render(template, locals())
         assert spelling(template, result), "%s is spelled wrong" % template
 
