@@ -212,13 +212,13 @@ def ensure_defaults(options, reqs):
     for key in reqs:
         if reqs[key] == None:
             # explicitly set to required
-            if not options.has_key(key):
+            if key not in options:
                 if key == "TRAILING":
                     raise ArgumentError("Additional arguments required after a -- on the command line.")
                 else:
                     raise ArgumentError("Option -%s is required by this command." % key)
         else:
-            if not options.has_key(key):
+            if key not in options:
                 options[key] = reqs[key]
 
 def command_module(mod, command, options, ending="_command"):
@@ -226,7 +226,10 @@ def command_module(mod, command, options, ending="_command"):
     function = mod.__dict__[command+ending]
     kwargs = determine_kwargs(function)
     ensure_defaults(options, kwargs)
-    return function(**options)
+    try:
+        return function(**options)
+    except TypeError, exc:
+        print "ERROR: ", exc
 
 
 def available_help(mod, ending="_command"):
