@@ -26,21 +26,22 @@ See lamson.args for more details.
 """
 
 from lamson import server, args, utils, queue, mail, routing
-import lamson
-import smtplib
-import sys
-import logging
-import signal
-import os
-import time
-import glob
-import imp
 from pkg_resources import resource_stream
 from zipfile import ZipFile
+import glob
+import imp
+import lamson
+import logging
+import os
+import signal
+import smtplib
+import sys
+import time
 
 
 def log_command(port=8825, host='127.0.0.1', debug=1, queue="", chroot=False,
-                cd=".", uid=False, gid=False, umask=False, pid="./run/log.pid"):
+                cd=".", uid=False, gid=False, umask=False, pid="./run/log.pid",
+               FORCE=False):
     """
     Runs a logging only server on the given hosts and port.  It logs
     each message it receives and also stores it to the run/queue 
@@ -48,21 +49,19 @@ def log_command(port=8825, host='127.0.0.1', debug=1, queue="", chroot=False,
 
     lamson log -port 8825 -host 127.0.0.1 -debug 1 \\
             -pid ./run/log.pid -chroot False  \\
-            -cd "." -umask False -uid False -gid False
+            -cd "." -umask False -uid False -gid False \\
+            -FORCE False
+
+    If you specify a uid/gid then this means you want to first change to
+    root, set everything up, and then drop to that UID/GID combination.
+    This is typically so you can bind to port 25 and then become "safe"
+    to continue operating as a non-root user.
+
+    If you give one or the other, this it will just change to that
+    uid or gid without doing the priv drop operation.
     """
-    if os.path.exists(pid):
-        print "PID file %s exists, delete it first." % pid
-        sys.exit(1)
-        return # for unit tests mocking sys.exit
-
-    utils.daemonize(pid, cd, chroot, uid, gid, umask, files_preserve=[])
-    sys.path.append(os.getcwd())
-    logging.basicConfig(filename="logs/logger.log", level=logging.DEBUG)
-
-    routing.Router.load(['lamson.handlers.log', 'lamson.handlers.queue'])
-
-    settings = utils.make_fake_settings(host, port)
-    settings.receiver.start()
+    loader = lambda: utils.make_fake_settings(host, port)
+    utils.start_server(pid, FORCE, chroot, cd, uid, gid, umask, loader)
 
 
 def send_command(port=8825, host='127.0.0.1', debug=1, sender=None, to=None,
@@ -121,20 +120,8 @@ def start_command(pid='./run/smtp.pid', FORCE=False, chroot=False, cd=".",
     lamson start -pid ./run/smtp.pid -FORCE False -chroot False -cd "." \\
             -umask False -uid False -gid False -boot config.boot
     """
-    if os.path.exists(pid):
-        if not FORCE:
-            print "PID file %s exists, so assuming Lamson is running.  Give -FORCE to force it to start." % pid
-            sys.exit(1)
-            return # for unit tests mocking sys.exit
-        else:
-            os.unlink(pid)
-
-    utils.daemonize(pid, cd, chroot, uid, gid, umask, files_preserve=[])
-
-    sys.path.append(os.getcwd())
-    settings = utils.import_settings(True, from_dir=os.getcwd(),
-                                     boot_module=boot)
-    settings.receiver.start()
+    loader = lambda: utils.import_settings(True, from_dir=os.getcwd(), boot_module=boot)
+    utils.start_server(pid, FORCE, chroot, cd, uid, gid, umask, loader)
 
 
 def stop_command(pid='./run/smtp.pid', KILL=False, ALL=False):
@@ -230,6 +217,8 @@ def queue_command(pop=False, get=False, keys=False, remove=False, count=False,
 
     lamson queue (-pop | -get | -remove | -count | -clear | -keys) -name run/queue
     """
+    print "Using queue: %r" % name
+
     q = queue.Queue(name)
 
     if pop:
@@ -253,23 +242,26 @@ def queue_command(pop=False, get=False, keys=False, remove=False, count=False,
         return # for unit tests mocking sys.exit
         
 
-def routes_command(TRAILING=['config.testing'], path=os.getcwd(), testing=True):
+def routes_command(TRAILING=['config.testing'], path=os.getcwd(), test=""):
     """
     Prints out valuable information about an application's routing configuration
     after everything is loaded and ready to go.  Helps debug problems with
     messages not getting to your handlers.  Path has the search paths you want
     separated by a ':' character, and it's added to the sys.path.
 
-    lamson routes -path $PWD -- config.testing
+    lamson routes -path $PWD -- config.testing -test ""
 
     It defaults to running your config.testing to load the routes. 
     If you want it to run the config.boot then give that instead:
 
     lamson routes -- config.boot
 
+    You can also test a potential target by doing -test EMAIL.
+
     """
     modules = TRAILING
     sys.path += path.split(':')
+    test_case_matches = []
 
     for module in modules:
         __import__(module, globals(), locals())
@@ -278,10 +270,24 @@ def routes_command(TRAILING=['config.testing'], path=os.getcwd(), testing=True):
     print "Routing TABLE: \n---"
     for format in routing.Router.REGISTERED:
         print "%r: " % format,
-        for func in routing.Router.REGISTERED[format][1]:
+        regex, functions = routing.Router.REGISTERED[format]
+        for func in functions:
             print "%s.%s " % (func.__module__, func.__name__),
+            match = regex.match(test)
+            if test and match:
+                test_case_matches.append((format, func, match))
+
         print "\n---"
 
+    if test_case_matches:
+        print "\nTEST address %r matches:" % test
+        for format, func, match in test_case_matches:
+            print "  %r %s.%s" % (format, func.__module__, func.__name__)
+            print "  -  %r" % (match.groupdict())
+    elif test:
+        print "\nTEST address %r didn't match anything." % test
+
+
 
 def gen_command(project=None):
     """
