@@ -5,10 +5,10 @@ from lamson.server import Relay
 from lamson.utils import configure_database
 import jinja2
 import logging
+import logging.config
 import os
 
-# configure logging to go to a log file
-logging.basicConfig(filename=settings.log_file, level=logging.DEBUG)
+logging.config.fileConfig("config/test_logging.conf")
 
 # the relay host to actually send the final message to (set debug=1 to see what
 # the relay is saying to the log server).
