@@ -26,6 +26,7 @@ from email.mime.base import MIMEBase
 from email.mime.image import MIMEImage
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
+from email.header import make_header, decode_header
 import mimetypes
 from os import path
 
@@ -42,9 +43,12 @@ class MailRequest(object):
         the name of a queue, so I wouldn't use it for much, definitely not for
         authentication.  From, To, and Data are exactly what they say they are,
         with Data being the full text of the message (not just the body).
+
+        WARNING: Data must is converted to 'ascii' encoding internally so that
+        email.message_from_string works in Python 2.6.
         """
-        self.Data = Data
-        self.msg = email.message_from_string(Data)
+        self.Data = Data.encode('ascii')
+        self.msg = email.message_from_string(self.Data)
         self.Peer = Peer
         self.From = From or self.msg['from']
         self.To = To or self.msg['to']
@@ -52,17 +56,6 @@ class MailRequest(object):
         if 'from' not in self.msg: self.msg['from'] = self.From
         if 'to' not in self.msg: self.msg['to'] = self.To
 
-        self.everyone = self.all_recipients()
-
-    def all_recipients(self):
-        """Taken from http://docs.python.org/lib/module-email.utils.html"""
-        frs = self.msg.get_all('from', [])
-        tos = self.msg.get_all('to', [])
-        ccs = self.msg.get_all('cc', [])
-        resent_tos = self.msg.get_all('resent-to', [])
-        resent_ccs = self.msg.get_all('resent-cc', [])
-        return getaddresses(frs + tos + ccs + resent_tos + resent_ccs)
-
     def all_parts(self):
         """
         Used to bust out the attachments (or parts) of an email.  It
@@ -104,11 +97,41 @@ class MailRequest(object):
         return key in self.msg
 
     def __getitem__(self, name):
-        return self.msg[name]
+        """
+        When you get from a MailRequest, it attempts to decode the header as best it can.
+        If you want the raw actual header then use the MailRequest.msg attribute.
+
+        It does everything it can to return a proper unicode string, and
+        if it can't it at least does a conversion with replace on 
+        the result so that you get something.
+
+        If the header doesn't start with the "=?" tag then it's assume
+        to not need conversion and it's just returned.
+        """
+        header = self.msg[name]
+        if header is None:
+            return header
+        elif header.strip().startswith("=?"):
+            decoded = decode_header(self.msg[name])
+            converted = (unicode(
+                x[0], encoding=x[1] or 'ascii', errors='replace')
+                for x in decoded)
+            return u"".join(converted)
+        else:
+            return header
+
 
     def __setitem__(self, name, val):
+        """Unlike __getitem__ this doesn't do anything to your header, you have to encode it
+        with the alternative MailRequest.encode_header call."""
         self.msg[name] = val
 
+    def encode_header(self, name, val, charset):
+        """This lets you use *ONE* charset on the header value.  If you need to set more than
+        one then you are on your own and should read the documentation for email.headers.Header."""
+        self.msg[name] = make_header([(val, charset)]).encode()
+
+
     def __delitem__(self, name):
         del self.msg[name]
 
@@ -258,3 +281,10 @@ class MailResponse(object):
     def __str__(self):
         return self.as_string()
 
+
+    def encode_header(self, name, val, charset):
+        """This lets you use *ONE* charset on the header value.  If you need to set more than
+        one then you are on your own and should read the documentation for email.headers.Header."""
+        self.headers[name] = make_header([(val, charset)]).encode()
+
+
