@@ -36,9 +36,14 @@ class Queue(object):
         It returns a (key, message) tuple for that item.
         """
         try:
-            key, msg = self.mbox.popitem()
-            return key, self.unstupify_python_message(msg)
-        except KeyError:
+            key = self.mbox.iterkeys().next()
+            if key:
+                msg = self.get(key)
+                self.remove(key)
+                return key, msg
+            else:
+                return None, None
+        except StopIteration:
             return None, None
 
     def get(self, key):
@@ -46,7 +51,11 @@ class Queue(object):
         Get the specific message referenced by the key.  The message is NOT
         removed from the queue.
         """
-        return self.unstupify_python_message(self.mbox.get(key))
+        file = self.mbox.get_file(key)
+        if not file: 
+            return None
+        return mail.MailRequest(self.dir, None, None, file.read())
+
 
     def remove(self, key):
         """Removes the queue, but not returned."""
@@ -56,14 +65,6 @@ class Queue(object):
         """Returns the number of messages in the queue."""
         return len(self.mbox)
 
-    def unstupify_python_message(self, msg):
-        """
-        Converts whatever bullshit Python's maildir returns into
-        something that can actually be used by a human.
-        """
-        data = str(msg) + "\n" + msg.fp.read()
-        return mail.MailRequest(self.dir, msg['from'], msg['to'], data)
-
     def clear(self):
         """
         Clears out the contents of the entire queue.
