@@ -36,6 +36,7 @@ import shelve
 import threading
 
 ROUTE_FIRST_STATE = 'START'
+LOG = logging.getLogger("routing")
 
 class StateStorage(object):
     """
@@ -185,6 +186,7 @@ class RoutingBase(object):
         self.STATE_STORE=MemoryStorage()
         self.HANDLERS=set()
         self.RELOAD=False
+        self.UNDELIVERABLE_QUEUE=None
         self.lock = threading.RLock()
         self.call_lock = threading.RLock()
 
@@ -276,6 +278,8 @@ class RoutingBase(object):
         """
         if self.RELOAD: self.reload()
 
+        called_count = 0
+
         for functions, kw in self.match(message['to']):
             to_call = []
             in_state_found = False
@@ -287,6 +291,8 @@ class RoutingBase(object):
                     to_call.append(fn)
                     in_state_found = True
 
+            called_count += len(to_call)
+
             for fn in to_call:
                 if lamson_setting(fn, 'nolocking'):
                     self.call_safely(fn, message, args, kw)
@@ -294,6 +300,15 @@ class RoutingBase(object):
                     with self.call_lock:
                         self.call_safely(fn, message, args, kw)
 
+        if called_count == 0:
+            if self.UNDELIVERABLE_QUEUE:
+                LOG.debug("Message to %r from %r undeliverable, putting in undeliverable queue.",
+                          message['to'], message['from'])
+                self.UNDELIVERABLE_QUEUE.push(message)
+            else:
+                LOG.debug("Message to %r from %r didn't match any handlers.",
+                          message['to'], message['from'])
+
 
     def call_safely(self, fn, message, args, kw):
         """
@@ -302,10 +317,10 @@ class RoutingBase(object):
         """
         try:
             fn(message, *args, **kw)
-            logging.debug("Message to %s was handled by %s.%s",
+            LOG.debug("Message to %s was handled by %s.%s",
                           message['to'], fn.__module__, fn.__name__)
         except:
-            logging.exception("!!! ERROR handling %s.%s", fn.__module__, fn.__name__)
+            LOG.exception("!!! ERROR handling %s.%s", fn.__module__, fn.__name__)
             self.set_state(fn, message, 'ERROR')
 
     def clear_states(self):
@@ -329,7 +344,10 @@ class RoutingBase(object):
         with self.lock:
             self.HANDLERS.update(handlers)
             for module in self.HANDLERS:
-                __import__(module, globals(), locals())
+                try:
+                    __import__(module, globals(), locals())
+                except:
+                    LOG.exception("ERROR IMPORTING %r MODULE:" % module)
 
     def reload(self):
         """
@@ -340,8 +358,10 @@ class RoutingBase(object):
             self.clear_routes()
             for module in sys.modules.keys():
                 if module in self.HANDLERS:
-                    reload(sys.modules[module])
-
+                    try:
+                        reload(sys.modules[module])
+                    except:
+                        LOG.exception("ERROR RELOADING %r MODULE:" % module)
 
 Router = RoutingBase()
 
