@@ -84,7 +84,7 @@ def queue(queue_dir=TEST_QUEUE):
 
 def clear_queue(queue_dir=TEST_QUEUE):
     """Clears the default test queue out, as created by lamson.testing.queue."""
-    queue(queue_dir=TEST_QUEUE).clear()
+    queue(queue_dir).clear()
 
 
 def database_session():
@@ -146,14 +146,18 @@ class TestConversation(object):
         self.Subject = Subject
 
     def begin(self):
-        """Clears out the queue and models so that you have a fresh start."""
+        """Clears out the queue and Router states so that you have a fresh start."""
         clear_queue()
+        routing.Router.clear_states()
 
     def deliver(self, To, From, Subject, Body):
         self.relay.send(To, From, Subject, Body)
 
     def say(self, To, Body, expect=None, Subject=None):
-        """Say something to To and expect a reply with a certain address."""
+        """
+        Say something to To and expect a reply with a certain address.
+        It returns the message expected or None.
+        """
         msg = None
 
         self.deliver(To, self.From, Subject or self.Subject, Body)
