@@ -23,9 +23,6 @@ def test_mail_request():
 
     assert_equal(str(msg), msg.Data, "Message isn't valid.")
 
-    assert_equal(msg.all_recipients(), [('', 'zedshaw@zedshaw.com'), 
-                                        ('', 'zedshaw@zedshaw.com')])
-
     # test the accessor parts of the base class that we proxy to
     assert_equal(msg.matches(re.compile("^(.*)@^(.*)")), None)
     assert_equal(msg.msg['From'], "zedshaw@zedshaw.com")
@@ -38,9 +35,26 @@ def test_mail_request():
 
     print repr(msg)
 
-
     return msg
 
+def test_character_encoded_header():
+    msg = mail.MailRequest("zedshaw.com", "zedshaw@zedshaw.com",
+                             ["zedshaw@zedshaw.com"], sample_message)
+    msg['Subject'] = '=?iso-8859-1?q?p=F6stal?='
+    assert msg['Subject'] == u'p\xf6stal', "%r" % msg['Subject']
+
+    msg = mail.MailRequest("zedshaw.com", "zedshaw@zedshaw.com",
+                             ["zedshaw@zedshaw.com"], sample_message)
+    msg.encode_header('Subject', u'p\xf6stal', 'iso-8859-1')
+
+    assert msg['Subject'] == u'p\xf6stal', "%r" % msg['Subject']
+
+    
+    sample = test_mail_response_plain_text()
+    sample.encode_header('Subject', u'p\xf6stal', 'iso-8859-1')
+
+    assert sample['Subject'] ==  '=?iso-8859-1?q?p=F6stal?=', "%r" % sample['Subject']
+
 
 def test_mail_response_plain_text():
     sample = mail.MailResponse(To="receiver@zedshaw.com", 
