@@ -14,7 +14,7 @@ def test_make_fake_settings():
 def test_import_settings():
     loader = view.LOADER
 
-    settings = utils.import_settings(True, from_dir='examples/osb', boot_module='config.testing')
+    settings = utils.import_settings(True, from_dir='tests', boot_module='config.testing')
     assert settings
     assert settings.receiver_config
     assert settings.database_config
@@ -39,6 +39,6 @@ def test_configure_database():
 
 
 def test_daemonize_not_fully():
-    context = utils.daemonize("run/tests.pid", ".", None, None, None, None, do_open=False)
-    context = utils.daemonize("run/tests.pid", ".", "/tmp", 0, 0, 0002, do_open=False)
+    context = utils.daemonize("run/tests.pid", ".", False, False, do_open=False)
+    context = utils.daemonize("run/tests.pid", ".", "/tmp", 0002, do_open=False)
     assert context
